# sendmail.rb - sendmail plugin for risc
#  - with resolving hostname.

require 'net/smtp'

add_after_check_hook do
  format_in_human_readable = Proc.new { |ipaddr,|
    hostname, = Socket.getnameinfo([Socket::AF_INET, 0, ipaddr])
    hostname =~ /^[0-9.:]+$/ ? ipaddr : "#{hostname.split('.')[0]}(#{ipaddr})"
  }
  mailserver = @conf.options['sendmail.mailserver'] || 'localhost'
  subject = @conf.options['sendmail.subject'] || 'SERVICE IS DEAD!'
  count =  @conf.options['sendmail.deadcount'] || 2
  sender = @conf.options['sendmail.sender'] || "risc@#{`/bin/hostname -f`.chop}"
  body = ''
  @conf.services.each do |host, value|
    if ( @store[host]['fails'] == count )
      body += "#{format_in_human_readable.call(host)}: DEAD! (since: #{@store[host]['last_alive'].strftime('%Y/%m/%d %T')})\n"
    end
    value.each do |service|
      proto = 'tcp'
      begin
        if ( @store["#{host}:#{proto}:#{service[0]}"]['fails'] == count )
          body += "#{format_in_human_readable.call(host)}:#{proto}:#{service[0]}: DEAD (since: #{@store["#{host}:#{proto}:#{service[0]}"]['last_alive'].strftime('%Y/%m/%d %T')})\n"
        end
      rescue NoMethodError
        next
      end
    end
  end
  if ( body != '' )
    mail = <<_EOT
From: risc@#{`/bin/hostname -f`.chop}
To: #{@conf.options['sendmail.recipients'].join(", ")}
Subject: #{subject}
Content-Type: text/plain; charset=us-ascii
MIME-Version: 1.0

#{body}
_EOT
    Net::SMTP.start(mailserver) do |smtp|
      smtp.send_mail(mail, sender, @conf.options['sendmail.recipients'])
    end
    @log.write('This is hook.')
  end
end
